DQM_multiple_record
===================

This is the class for computing the DQM for multiple records. It supports to compute an overall DQM for the whole dataset,
and compute a set of individual DQMs for each record in the dataset.

.. autoclass:: QPrism.Sensor.DQM.DQM_multiple_record
    :members:
    :undoc-members:
    :show-inheritance: